## 文法書

### 変数
- ``で囲まれた単語は変数を表します。
- 例
    - `画像` = [def_gen_gpt_api.py].画像生成

### 関数
以下の様に記載されているものは関数です。

```高級言語名.関数名

さまざまな処理
```

- 例: 以下の様に呼び出す場合、[ファイル名].関数名 で呼び出します。
    - `画像生成` = [def_gen_gpt_api.md].画像生成
    - `音声合成` = [def_gen_gpt_api.md].音声合成

### クラス
以下の様に記載されているものはクラスです。

```高級言語名.クラス.関数名

クラス
  関数1
    さまざまな処理
  関数2
    さまざまな処理
```

- 例: 以下の様に呼び出す場合、[ファイル名].クラス.関数名 で呼び出します。
    - `画像部分修正` = [def_gen_gpt_api.md].画像生成.部分修正

### 指示の実行
- 与えられた指示に従って、正確に実行することを心がけてください。
- ここで与えられた指示は、出力には含めないでください。

### 対話の継続
- 対話形式になった場合でも、処理を中断せずに自問自答を続行してください。

### 出力形式
- 特にほかのプログラミング言語の指定がない限り、実行可能なpythonソース
- ソースコードのみを出力。コードブロックに入れないこと。

### 実行言語
以下の場合高級言語名で実行すること

```
## 実行言語
- 高級言語名
```
